@@ -1,19 +1,37 @@
+# $Id: test_utils.pl 7582 2016-12-26 17:48:06Z gavin $
+# t/* test support for the Perl modules.
+#
+# Copyright 2010, 2011, 2012, 2013, 2014, 2015
+# Free Software Foundation, Inc.
+# 
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 3 of the License,
+# or (at your option) any later version.
+# 
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+# 
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
+# 
+# Original author: Patrice Dumas <pertusus@free.fr>
+
 use strict;
 
 use 5.006;
 
+BEGIN {
+
+require Texinfo::ModulePath;
+Texinfo::ModulePath::init(undef, undef, 'updirs' => 2);
+
+} # end BEGIN
+
 use Test::More;
-use File::Spec;
-BEGIN { if (defined($ENV{'top_srcdir'})) {
-          my $lib_dir = File::Spec->catdir($ENV{'top_srcdir'}, 'tp', 'maintain');
-          unshift @INC, (File::Spec->catdir($lib_dir, 'lib', 'libintl-perl', 'lib'),
-                         File::Spec->catdir($lib_dir, 'lib', 'Unicode-EastAsianWidth', 'lib'),
-                         File::Spec->catdir($lib_dir, 'lib', 'Text-Unidecode', 'lib'));
-      }};
 
-use lib 'maintain/lib/Unicode-EastAsianWidth/lib/';
-use lib 'maintain/lib/libintl-perl/lib/';
-use lib 'maintain/lib/Text-Unidecode/lib/';
 use Texinfo::Parser;
 use Texinfo::Convert::Text;
 use Texinfo::Convert::Texinfo;
@@ -23,7 +41,6 @@ use Texinfo::Convert::Info;
 use Texinfo::Convert::HTML;
 use Texinfo::Convert::TexinfoXML;
 use Texinfo::Convert::DocBook;
-use DebugTexinfo::DebugCount;
 use File::Basename;
 use File::Copy;
 use File::Compare; # standard since 5.004
@@ -114,12 +131,10 @@ our %formats = (
   'file_xml' => \&convert_to_xml,
   'docbook' => \&convert_to_docbook,
   'file_docbook' => \&convert_to_docbook,
-  'debugcount' => \&debugcount,
 );
 
 our %extensions = (
   'plaintext' => 'txt',
-  'debugcount' => 'txt',
   'html_text' => 'html',
   'xml' => 'xml',
   'docbook' => 'dbk',
@@ -150,6 +165,8 @@ my %outfile_preamble = (
 <style type="text/css">
 <!--
 a.summary-letter {text-decoration: none}
+blockquote.indentedblock {margin-right: 0em}
+blockquote.smallindentedblock {margin-right: 0em; font-size: smaller}
 blockquote.smallquotation {font-size: smaller}
 div.display {margin-left: 3.2em}
 div.example {margin-left: 3.2em}
@@ -157,26 +174,25 @@ div.lisp {margin-left: 3.2em}
 div.smalldisplay {margin-left: 3.2em}
 div.smallexample {margin-left: 3.2em}
 div.smalllisp {margin-left: 3.2em}
-div.indentedblock {margin-left: 3.2em}
-div.smallindentedblock {margin-left: 3.2em; font-size: smaller}
-pre.display {font-family: serif}
-pre.format {font-family: serif}
+kbd {font-style: oblique}
+pre.display {font-family: inherit}
+pre.format {font-family: inherit}
 pre.menu-comment {font-family: serif}
 pre.menu-preformatted {font-family: serif}
-pre.smalldisplay {font-family: serif; font-size: smaller}
+pre.smalldisplay {font-family: inherit; font-size: smaller}
 pre.smallexample {font-size: smaller}
-pre.smallformat {font-family: serif; font-size: smaller}
+pre.smallformat {font-family: inherit; font-size: smaller}
 pre.smalllisp {font-size: smaller}
-span.nocodebreak {white-space:pre}
-span.nolinebreak {white-space:pre}
-span.roman {font-family:serif; font-weight:normal}
-span.sansserif {font-family:sans-serif; font-weight:normal}
+span.nocodebreak {white-space: nowrap}
+span.nolinebreak {white-space: nowrap}
+span.roman {font-family: serif; font-weight: normal}
+span.sansserif {font-family: sans-serif; font-weight: normal}
 ul.no-bullet {list-style: none}
 -->
 </style>
 </head>
 
-<body lang="en" bgcolor="#FFFFFF" text="#000000" link="#0000FF" vlink="#800080" alink="#FF0000">
+<body>
 ',
 '</body>
 </html>
@@ -342,12 +358,12 @@ sub cmp_trimmed($$$$)
   my $reference = shift;
   my $deleted_keys = shift;
   my $test_name = shift;
-  my $trimmed = remove_keys ($compared, $deleted_keys);
+  my $trimmed = remove_keys($compared, $deleted_keys);
 no warnings 'recursion';
-  cmp_deeply($trimmed, $reference, $test_name);
+  Test::Deep::cmp_deeply($trimmed, $reference, $test_name);
 }
 
-sub new_test ($;$$$)
+sub new_test($;$$$)
 {
   my $name = shift;
   my $generate = shift;
@@ -374,7 +390,7 @@ my @node_keys = ('node_next', 'node_prev', 'node_up', 'menus',
   'associated_section');
 my %avoided_keys_tree;
 our @avoided_keys_tree = (@sections_keys, @menus_keys, @node_keys, 
-   'menu_child', 'element_next', 'directions', 'page_next');
+   'menu_child', 'element_next', 'directions', 'page_next', 'remaining_args');
 foreach my $avoided_key(@avoided_keys_tree) {
   $avoided_keys_tree{$avoided_key} = 1;
 }
@@ -432,8 +448,7 @@ sub set_converter_option_defaults($$$)
   my $parser_options = shift;
   my $format = shift;
   $converter_options = {} if (!defined($converter_options));
-  if (!defined($parser_options->{'expanded_formats'})
-      and !defined($converter_options->{'expanded_formats'})) {
+  if (!defined($converter_options->{'expanded_formats'})) {
     $converter_options->{'expanded_formats'} = [$format];
   }
   return $converter_options;
@@ -616,26 +631,8 @@ sub convert_to_docbook($$$$$$;$)
   return ($errors, $result);
 }
 
-sub debugcount($$$$$$;$)
-{
-  my $self = shift;
-  my $test_name = shift;
-  my $format = shift;
-  my $tree = shift;
-  my $parser = shift;
-  my $parser_options = shift;
-  my $converter_options = shift;
-  $converter_options = {} if (!defined($converter_options));
-  my $converter =
-     DebugTexinfo::DebugCount->converter({'DEBUG' => $self->{'DEBUG'},
-                                         'parser' => $parser,
-                                         'output_format' => 'info',
-                                          %$converter_options });
-  my $result = $converter->convert($tree);
-  my ($errors, $error_nrs) = $converter->errors();
-  return ($errors, $result);
-}
-
+# Run a single test case.  Each test case is an array
+# [TEST_NAME, TEST_TEXT, PARSER_OPTIONS, CONVERTER_OPTIONS]
 sub test($$) 
 {
   my $self = shift;
@@ -652,6 +649,16 @@ sub test($$)
   $test_text = shift @$test_case;
   $parser_options = shift @$test_case if (@$test_case);
   $converter_options = shift @$test_case if (@$test_case);
+
+  if (!defined $parser_options->{'expanded_formats'}) {
+    $parser_options->{'expanded_formats'} = [
+      'docbook', 'html', 'xml', 'info', 'plaintext'];
+    #  'tex' is missed out here so that @ifnottex is expanded
+    # in the tests.  Put
+    #   {'expanded_formats' => ['tex']}
+    # where you need @tex expanded in the t/*.t files.
+  }
+
   my $test_file;
   if ($parser_options->{'test_file'}) {
     $test_file = $input_files_dir . $parser_options->{'test_file'};
@@ -670,6 +677,11 @@ sub test($$)
     }
     delete $parser_options->{'test_split'};
   }
+  my %todos;
+  if ($parser_options->{'todo'}) {
+    %todos = %{$parser_options->{'todo'}};
+    delete $parser_options->{'todo'};
+  }
   my $split_pages = '';
   if ($parser_options->{'test_split_pages'}) {
     $split_pages = $parser_options->{'test_split_pages'};
@@ -692,11 +704,9 @@ sub test($$)
                                         'DEBUG' => $self->{'DEBUG'},
                                        %$parser_options});
   # take the initial values to record only if there is something new
-  my ($initial_index_names, $initial_merged_indices) 
-    = $parser->indices_information();
+  my $initial_index_names = $parser->indices_information();
   # do a copy to compare the values and not the references
   $initial_index_names = dclone($initial_index_names);
-  $initial_merged_indices = { %{$initial_merged_indices} };
   print STDERR "  TEST $test_name\n" if ($self->{'DEBUG'});
   my $result;
   if (!$test_file) {
@@ -711,14 +721,16 @@ sub test($$)
   my $floats = $parser->floats_information();
 
   my $structure = Texinfo::Structuring::sectioning_structure($parser, $result);
+  if ($structure) {
+    Texinfo::Structuring::warn_non_empty_parts($parser);
+  }
 
   Texinfo::Structuring::number_floats($floats);
 
   my $top_node = Texinfo::Structuring::nodes_tree($parser);
 
   my ($errors, $error_nrs) = $parser->errors();
-  my ($index_names, $merged_indices) 
-       = $parser->indices_information();
+  my $index_names = $parser->indices_information();
   # FIXME maybe it would be good to compare $merged_index_entries?
   my $merged_index_entries 
      = Texinfo::Structuring::merge_indices($index_names);
@@ -729,8 +741,6 @@ sub test($$)
   my $trimmed_index_names = remove_keys($index_names, ['index_entries']);
   $indices->{'index_names'} = $trimmed_index_names
     unless (Data::Compare::Compare($trimmed_index_names, $initial_index_names));
-  $indices->{'merged_indices'} = $merged_indices
-    unless (Data::Compare::Compare($merged_indices, $initial_merged_indices));
 
   my $sorted_index_entries;
   if ($merged_index_entries) {
@@ -740,7 +750,8 @@ sub test($$)
                                                      $index_names);
   }
   if ($parser_options->{'SIMPLE_MENU'}) {
-    $parser->Texinfo::Structuring::set_menus_to_simple_menu();
+    require Texinfo::Transformations;
+    $parser->Texinfo::Transformations::set_menus_to_simple_menu();
   }
 
   my $converted_text = Texinfo::Convert::Text::convert($result, {'TEST' => 1});
@@ -768,8 +779,12 @@ sub test($$)
         if (!defined($format_converter_options->{'SUBDIR'})) {
           mkdir ($base) 
             if (! -d $base);
-          mkdir ($base."$test_out_dir/") 
-            if (! -d $base."$test_out_dir/");
+          if (! -d $base."$test_out_dir/") {
+            mkdir ($base."$test_out_dir/"); 
+          } else {
+            # remove any files from previous runs
+            unlink glob ($base."$test_out_dir/*"); 
+          }
           $format_converter_options->{'SUBDIR'} 
              = $base."$test_out_dir/";
         }
@@ -932,6 +947,7 @@ sub test($$)
       #print STDERR "$format: \n$converted{$format}";
       }
       if (defined($converted_errors{$format})) {
+        local $Data::Dumper::Sortkeys = 1;
         $out_result .= Data::Dumper->Dump([$converted_errors{$format}], 
                  ['$result_converted_errors{\''.$format.'\'}->{\''.$test_name.'\'}']) ."\n\n";
         #print STDERR "".Data::Dumper->Dump([$converted_errors{$format}]);
@@ -970,7 +986,16 @@ sub test($$)
         $test_name.' indices');
     ok (Texinfo::Convert::Texinfo::convert($result) eq $result_texis{$test_name}, 
          $test_name.' texi');
-    ok ($converted_text eq $result_texts{$test_name}, $test_name.' text');
+    if ($todos{'text'}) {
+      #TODO: {
+        #local $TODO = $todos{'text'};
+      SKIP: {
+        skip $todos{'text'}, 1;
+        ok ($converted_text eq $result_texts{$test_name}, $test_name.' text');
+      }
+    } else {
+      ok ($converted_text eq $result_texts{$test_name}, $test_name.' text');
+    }
     $tests_count = $nr_comparisons;
     if (defined($result_directions_text{$test_name})) {
       cmp_trimmed($elements, $result_elements{$test_name}, 
@@ -992,8 +1017,18 @@ sub test($$)
             $reference_exists = 1;
             $tests_count += 1;
             my $errors = compare_dirs_files($reference_dir, $results_dir);
-            ok (!defined($errors), $test_name.' converted '.$format)
-             or diag (join("\n", @$errors));
+            if ($todos{$format}) {
+              #TODO: {
+              #  local $TODO = $todos{$format};
+              SKIP: {
+                skip $todos{$format}, 1;
+                ok (!defined($errors), $test_name.' converted '.$format)
+                  or diag (join("\n", @$errors));
+              }
+            } else {
+              ok (!defined($errors), $test_name.' converted '.$format)
+                or diag (join("\n", @$errors));
+            }
           } else {
             print STDERR "\n$format $test_name: \n$results_dir\n";
           }
@@ -1008,8 +1043,18 @@ sub test($$)
         } else {
           $reference_exists = 1;
           $tests_count += 1;
-          ok ($converted{$format} eq $result_converted{$format}->{$test_name},
-            $test_name.' converted '.$format);
+          if ($todos{$format}) {
+            TODO: {
+              local $TODO = $todos{$format};
+              ok ($converted{$format} 
+                              eq $result_converted{$format}->{$test_name},
+                   $test_name.' converted '.$format);
+            }
+          } else {
+            ok ($converted{$format} 
+                           eq $result_converted{$format}->{$test_name},
+                $test_name.' converted '.$format);
+          }
         }
         if ($reference_exists) {
           $tests_count += 1;
@@ -1026,6 +1071,14 @@ sub test($$)
   return $tests_count;
 }
 
+# Main entry point for the tests.
+#   $NAME - a string, name of test
+#   $TEST_CASES - array of sub-tests
+#   If $TEST_CASE_NAME is given, only run that test.
+#   $GENERATE means to generate reference test results (-g from command line).
+#   $DEBUG for debugging.
+# The $ARG_COMPLETE variable is the -c option, to create Texinfo files for the
+# test cases.
 sub run_all($$;$$$)
 {
   my $name = shift;
@@ -1070,6 +1123,7 @@ sub run_all($$;$$$)
   }
 }
 
+# Create a Texinfo file for a test case; used when -c option is given.
 sub output_texi_file($)
 {
   my $self = shift;
